ConfigService class
Manages SM CLI project configuration.
Saves and reads the .sm_cli_config file in the project root.
This allows sm make feature to auto-detect state management
without asking every time.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
readStateManagement(
String projectName) → String -
Reads state management from
.sm_cli_config. -
saveConfig(
{required String projectName, required String stateManagement}) → void -
Saves project config to
.sm_cli_configfile.